import { IEdgeInsets, IPdfReport, IReport, IReportBlock, ITableColWidth, ITableRow, ITableRowV2 } from "./models";
export declare class Report implements IReport {
    dir?: string;
    lang?: "en" | "ar";
    fontSize?: number;
    margin?: IEdgeInsets;
    blocks: IReportBlock[];
    constructor(blocks: IReportBlock[], options?: {
        margin?: IEdgeInsets;
        fontSize?: number;
        dir?: string;
    });
}
declare type PdfReportOptions = {
    margin?: IEdgeInsets;
    fontSize?: number;
    dir?: string;
};
export declare class PdfReport implements IPdfReport {
    dir?: string;
    fontSize?: number;
    margin?: IEdgeInsets;
    header?: IReportBlock;
    detail: IReportBlock[];
    footer?: IReportBlock;
    constructor(detail: IReportBlock[], options?: PdfReportOptions);
    setHeader(header: IReportBlock): this;
    setFooter(footer: IReportBlock): this;
    setOptions(options: PdfReportOptions): void;
}
export declare class Block implements IReportBlock {
    type: string;
    value?: string;
    textAlign?: string;
    bold?: boolean;
    noBorder?: boolean;
    noBottomBorder?: boolean;
    noLeftBorder?: boolean;
    noRightBorder?: boolean;
    noTopBorder?: boolean;
    noHorizontalInsideBorder?: boolean;
    noVerticalInsideBorder?: boolean;
    lineSpacing?: number;
    border?: number;
    align?: string;
    textDir?: string;
    paddingBottom?: number;
    paddingLeft?: number;
    paddingRight?: number;
    paddingTop?: number;
    size?: number;
    tableRows?: ITableRow[];
    tableRowsV2?: ITableRowV2[];
    repeatFirstRow?: boolean;
    enumName?: string;
    flexes?: number[];
    colWidths?: ITableColWidth[];
    expand?: boolean;
    column?: Block[];
    row?: Block[];
    constructor(type: string);
    setBold(): this;
    setLineSpacing(value: number): this;
    setNoBorder(): this;
    setNoOuterBorders(): this;
    setNoInnerBorders(): this;
    setBorder(value: number): this;
    setTextAlign(value: string): this;
    justify(): this;
    textLeft(): this;
    textRight(): this;
    textCenter(): this;
    center(): this;
    left(): this;
    right(): this;
    pb(value: number): this;
    pl(value: number): this;
    pr(value: number): this;
    pt(value: number): this;
    /**@deprecated use .p instead */
    paddingAll(value: number): this;
    p(value: number): this;
    /**@deprecated use .ph instead */
    paddingRightLeft(value: number): this;
    ph(value: number): this;
    pv(value: number): this;
    setSize(value?: number): this;
    setTextDir(value: string): this;
    setAlign(value: string): this;
    ltr(): this;
    rtl(): this;
}
export declare class Qr extends Block {
    constructor(value: string);
}
export declare class Spacer extends Block {
    constructor(value?: number);
}
export declare class Pdf417 extends Block {
    constructor(value: string);
}
export declare class Gap extends Block {
    constructor(size?: number);
}
export declare class PageBreak extends Block {
    constructor();
}
export declare class RText extends Block {
    constructor(value: string, enumName?: string);
}
export declare class Column extends Block {
    constructor(column?: Block[]);
    add(block: Block): this;
    setExpand(): this;
}
export declare class Row extends Block {
    constructor(row?: Block[]);
    add(child: Block): this;
    setExpand(): this;
}
export declare class Paragraph extends RText {
    constructor(value: string);
}
export declare class ParagraphAr extends RText {
    constructor(value: string);
}
interface TableOptions {
    headerFontSize?: number;
    repeatFirstRow?: boolean;
    /**@deprecated use .p instead */
    paddingAll?: number;
    /**@deprecated use .ph instead */
    paddingRightLeft?: number;
    rows?: {
        ph?: number;
        pv?: number;
        p?: number;
    };
    header?: {
        ph?: number;
        pv?: number;
        p?: number;
    };
}
/** @deprecated use TableV2 please */
export declare class Table extends Block {
    selectedRow?: ITableRow;
    constructor(headers?: string[], tableOptions?: Omit<TableOptions, "rows">);
    addRow(blocks?: Block[]): Table;
    addColumn(blocks: Block[]): this;
    setFlexes(ints: number[]): this;
    build(): this;
}
export declare class TableV2 extends Block {
    protected tableOptions?: TableOptions | undefined;
    selectedRow?: ITableRowV2;
    constructor(headers: string[], tableOptions?: TableOptions | undefined);
    addRow(blocks?: Block[]): this;
    addCell(block: Block): this;
    setFlexes(ints: number[]): this;
    build(): this;
}
/**
 * Wraps the given text in bold markdown syntax, or returns "**_UNDEFINED_**" if the text is null or undefined.
 * @param text - The text to be wrapped in bold markdown syntax.
 * @returns The input text wrapped in bold markdown syntax, or "**_UNDEFINED_**" if the input text is null or undefined.
 */
export declare function ss(text: string | number | undefined | null): string;
/**
 * Returns the given text as a string, or a string of slashes if the text is falsy.
 * @param text - The text to return as a string, or a falsy value to return a string of slashes.
 * @returns The given text as a string, or a string of slashes if the text is falsy.
 */
export declare function orSlashes(text: string | number | undefined | null): string;
export declare function orSlashesB(text: string | number | undefined | null): string;
/**
 * Converts a value to a string, or returns "**_UNDEFINED_**" if the value is null or undefined.
 * @param text - The value to convert to a string.
 * @returns A string representation of the input value, or "**_UNDEFINED_**" if the input value is null or undefined.
 */
export declare function s(text: string | number | undefined | null): string;
/**
 * Wraps the given text in bold markdown syntax and trim it, or returns "**_UNDEFINED_**" if the text is null or undefined.
 * If the text is undefined, null, or an empty string, returns "**_UNDEFINED_**".
 * @param text - The text to emphasize.
 * @returns The emphasized text, or "**_UNDEFINED_**" if the text is undefined, null, or an empty string.
 */
export declare function sst(text: string | number | undefined | null): string;
export {};
